@@ -708,7 +708,7 @@ rook.f"> */
 /* > \endverbatim */
 
 /*  ===================================================================== */
-/* Subroutine */ int ssytf2_rook_(char *uplo, integer *n, real *a, integer *
+/* Subroutine */ void ssytf2_rook_(char *uplo, integer *n, real *a, integer *
 	lda, integer *ipiv, integer *info)
 {
     /* System generated locals */
@@ -718,17 +718,17 @@ rook.f"> */
     /* Local variables */
     logical done;
     integer imax, jmax;
-    extern /* Subroutine */ int ssyr_(char *, integer *, real *, real *, 
+    extern /* Subroutine */ void ssyr_(char *, integer *, real *, real *, 
 	    integer *, real *, integer *);
     integer i__, j, k, p;
     real t, alpha;
     extern logical lsame_(char *, char *);
-    extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
+    extern /* Subroutine */ void sscal_(integer *, real *, real *, integer *);
     real sfmin;
     integer itemp, kstep;
     real stemp;
     logical upper;
-    extern /* Subroutine */ int sswap_(integer *, real *, integer *, real *, 
+    extern /* Subroutine */ void sswap_(integer *, real *, integer *, real *, 
 	    integer *);
     real d11, d12, d21, d22;
     integer ii, kk, kp;
@@ -769,7 +769,7 @@ rook.f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("SSYTF2_ROOK", &i__1, (ftnlen)11);
-	return 0;
+	return;
     }
 
 /*     Initialize ALPHA for use in choosing pivot block size. */
@@ -1388,7 +1388,7 @@ L42:
 
 L70:
 
-    return 0;
+    return;
 
 /*     End of SSYTF2_ROOK */
 
