@@ -744,7 +744,7 @@ f"> */
 /* > \endverbatim */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int zlatps_(char *uplo, char *trans, char *diag, char *
+/* Subroutine */ void zlatps_(char *uplo, char *trans, char *diag, char *
 	normin, integer *n, doublecomplex *ap, doublecomplex *x, doublereal *
 	scale, doublereal *cnorm, integer *info)
 {
@@ -761,7 +761,7 @@ f"> */
     doublecomplex tjjs;
     doublereal xmax, grow;
     integer i__, j;
-    extern /* Subroutine */ int dscal_(integer *, doublereal *, doublereal *, 
+    extern /* Subroutine */ void dscal_(integer *, doublereal *, doublereal *, 
 	    integer *);
     extern logical lsame_(char *, char *);
     doublereal tscal;
@@ -773,7 +773,7 @@ f"> */
     logical upper;
     extern /* Double Complex */ VOID zdotu_(doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    extern /* Subroutine */ int zaxpy_(integer *, doublecomplex *, 
+    extern /* Subroutine */ void zaxpy_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *), ztpsv_(
 	    char *, char *, char *, integer *, doublecomplex *, doublecomplex 
 	    *, integer *), dlabad_(doublereal *, 
@@ -782,7 +782,8 @@ f"> */
     integer ip;
     doublereal xj;
     extern integer idamax_(integer *, doublereal *, integer *);
-    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen), zdscal_(
+    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
+    extern void zdscal_(
 	    integer *, doublereal *, doublecomplex *, integer *);
     doublereal bignum;
     extern integer izamax_(integer *, doublecomplex *, integer *);
@@ -834,13 +835,13 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZLATPS", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
 /*     Determine machine dependent parameters to control overflow. */
@@ -1715,7 +1716,7 @@ L210:
 	dscal_(n, &d__1, &cnorm[1], &c__1);
     }
 
-    return 0;
+    return;
 
 /*     End of ZLATPS */
 
