@@ -624,7 +624,7 @@ f"> */
 /* > \ingroup complex16OTHERcomputational */
 
 /*  ===================================================================== */
-/* Subroutine */ int zsptri_(char *uplo, integer *n, doublecomplex *ap, 
+/* Subroutine */ void zsptri_(char *uplo, integer *n, doublecomplex *ap, 
 	integer *ipiv, doublecomplex *work, integer *info)
 {
     /* System generated locals */
@@ -638,11 +638,11 @@ f"> */
     extern logical lsame_(char *, char *);
     integer kstep;
     logical upper;
-    extern /* Subroutine */ int zcopy_(integer *, doublecomplex *, integer *, 
+    extern /* Subroutine */ void zcopy_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *);
     extern /* Double Complex */ VOID zdotu_(doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *);
-    extern /* Subroutine */ int zswap_(integer *, doublecomplex *, integer *, 
+    extern /* Subroutine */ void zswap_(integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *), zspmv_(char *, integer *, 
 	    doublecomplex *, doublecomplex *, doublecomplex *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *);
@@ -680,13 +680,13 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZSPTRI", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
 /*     Check that the diagonal matrix D is nonsingular. */
@@ -699,7 +699,7 @@ f"> */
 	for (*info = *n; *info >= 1; --(*info)) {
 	    i__1 = kp;
 	    if (ipiv[*info] > 0 && (ap[i__1].r == 0. && ap[i__1].i == 0.)) {
-		return 0;
+		return;
 	    }
 	    kp -= *info;
 /* L10: */
@@ -713,7 +713,7 @@ f"> */
 	for (*info = 1; *info <= i__1; ++(*info)) {
 	    i__2 = kp;
 	    if (ipiv[*info] > 0 && (ap[i__2].r == 0. && ap[i__2].i == 0.)) {
-		return 0;
+		return;
 	    }
 	    kp = kp + *n - *info + 1;
 /* L20: */
@@ -1047,7 +1047,7 @@ L80:
 	;
     }
 
-    return 0;
+    return;
 
 /*     End of ZSPTRI */
 
