@@ -725,7 +725,7 @@ static integer c__1 = 1;
 /* >      Algorithms, 50(1):33-65, 2009. */
 /* > */
 /*  ===================================================================== */
-/* Subroutine */ int zunbdb4_(integer *m, integer *p, integer *q, 
+/* Subroutine */ void zunbdb4_(integer *m, integer *p, integer *q, 
 	doublecomplex *x11, integer *ldx11, doublecomplex *x21, integer *
 	ldx21, doublereal *theta, doublereal *phi, doublecomplex *taup1, 
 	doublecomplex *taup2, doublecomplex *tauq1, doublecomplex *phantom, 
@@ -743,20 +743,21 @@ static integer c__1 = 1;
     integer i__, j;
     doublereal s;
     integer ilarf, llarf;
-    extern /* Subroutine */ int zscal_(integer *, doublecomplex *, 
+    extern /* Subroutine */ void zscal_(integer *, doublecomplex *, 
 	    doublecomplex *, integer *);
     integer childinfo;
-    extern /* Subroutine */ int zlarf_(char *, integer *, integer *, 
+    extern /* Subroutine */ void zlarf_(char *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, doublecomplex *, 
 	    integer *, doublecomplex *), zdrot_(integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublereal *, doublereal *);
     extern doublereal dznrm2_(integer *, doublecomplex *, integer *);
-    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen), zlacgv_(
+    extern /* Subroutine */ int xerbla_(char *, integer *, ftnlen);
+    extern void zlacgv_(
 	    integer *, doublecomplex *, integer *);
     logical lquery;
     integer iorbdb5, lorbdb5;
-    extern /* Subroutine */ int zunbdb5_(integer *, integer *, integer *, 
+    extern /* Subroutine */ void zunbdb5_(integer *, integer *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, doublecomplex *, integer *, 
 	    doublecomplex *, integer *, integer *), zlarfgp_(integer *, 
@@ -832,9 +833,9 @@ static integer c__1 = 1;
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZUNBDB4", &i__1, (ftnlen)7);
-	return 0;
+	return;
     } else if (lquery) {
-	return 0;
+	return;
     }
 
 /*     Reduce columns 1, ..., M-Q of X11 and X21 */
@@ -986,7 +987,7 @@ static integer c__1 = 1;
 	zlacgv_(&i__2, &x21[*m - *q + i__ - *p + i__ * x21_dim1], ldx21);
     }
 
-    return 0;
+    return;
 
 /*     End of ZUNBDB4 */
 
